==> genometools-1.2.0.tar.gz: genometools-1.2.0/src/extended/gff3_output.c <==
/*
  Copyright (c) 2006, 2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006, 2008 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#include "core/assert_api.h"
#include "core/undef.h"
#include "extended/genome_node.h"
#include "extended/gff3_output.h"

void gt_gff3_output_leading(GtFeatureNode *gf, GtGenFile *outfp)
{
  GtGenomeNode *gn;
  gt_assert(gf);
  gn = (GtGenomeNode*) gf;
  gt_genfile_xprintf(outfp, "%s\t%s\t%s\t%lu\t%lu\t",
                     gt_str_get(gt_genome_node_get_seqid(gn)),
                     gt_feature_node_get_source(gf),
                     gt_feature_node_get_type(gf),
                     gt_genome_node_get_start(gn),
                     gt_genome_node_get_end(gn));
  if (gt_feature_node_score_is_defined(gf))
    gt_genfile_xprintf(outfp, "%.3g", gt_feature_node_get_score(gf));
  else
    gt_genfile_xfputc('.', outfp);
  gt_genfile_xprintf(outfp, "\t%c\t%c\t",
                     GT_STRAND_CHARS[gt_feature_node_get_strand(gf)],
                     GT_PHASE_CHARS[gt_feature_node_get_phase(gf)]);
}

==> genometools-1.3.4.tar.gz: genometools-1.3.4/src/extended/gff3_output.c <==
/*
  Copyright (c) 2006, 2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006, 2008 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#include "core/assert_api.h"
#include "core/undef.h"
#include "extended/genome_node.h"
#include "extended/gff3_output.h"

void gt_gff3_output_leading(GtFeatureNode *gf, GtFile *outfp)
{
  GtGenomeNode *gn;
  gt_assert(gf);
  gn = (GtGenomeNode*) gf;
  gt_file_xprintf(outfp, "%s\t%s\t%s\t%lu\t%lu\t",
                     gt_str_get(gt_genome_node_get_seqid(gn)),
                     gt_feature_node_get_source(gf),
                     gt_feature_node_get_type(gf),
                     gt_genome_node_get_start(gn),
                     gt_genome_node_get_end(gn));
  if (gt_feature_node_score_is_defined(gf))
    gt_file_xprintf(outfp, "%.3g", gt_feature_node_get_score(gf));
  else
    gt_file_xfputc('.', outfp);
  gt_file_xprintf(outfp, "\t%c\t%c\t",
                     GT_STRAND_CHARS[gt_feature_node_get_strand(gf)],
                     GT_PHASE_CHARS[gt_feature_node_get_phase(gf)]);
}
